@@ -1,4 +1,4 @@
-# $Id: cmon.py 1577 2016-11-22 22:58:30Z mwall $
+# $Id: cmon.py 1651 2017-01-16 18:10:37Z mwall $
 # Copyright 2013 Matthew Wall
 """weewx module that records cpu, memory, disk, and network usage.
 
@@ -128,7 +128,7 @@ from weewx.drivers import AbstractDevice
 from weewx.engine import StdService
 
 DRIVER_NAME = "ComputerMonitor"
-DRIVER_VERSION = "0.15"
+DRIVER_VERSION = "0.16"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -722,7 +722,8 @@ class ComputerMonitor(StdService):
 
     def get_data(self, now_ts, last_ts):
         record = self.collector.get_data(now_ts)
-        record['interval'] = int((now_ts - last_ts) / 60)
+        # calculate the interval (an integer), and be sure it is non-zero
+        record['interval'] = max(1, int((now_ts - last_ts) / 60))
         return record
         
 
